@@ -3,6 +3,7 @@
 from netmiko import ConnectHandler
 from collections import namedtuple
 
+
 class huawei_S5720(object):
     def __init__(self,ac_info,dev_info):
         self.username = ac_info.username
@@ -39,7 +40,7 @@ class huawei_S5720(object):
             return False
 
 
-    def get_running_config(self, filter_str = 'NULL', show_config_cmd='show running-config'):
+    def get_running_config(self, filter_str = 'NULL', show_config_cmd='display current-configuration'):
         """
         获取设备配置信息，如果添加 running_content 参数，可以获取指定的配置信息
         返回的是一个字符串，这个字符串就是设备配置，或者指定的配置
